summaryrefslogtreecommitdiff
path: root/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/lpc4330-xplorer/src/up_buttons.c')
-rw-r--r--nuttx/configs/lpc4330-xplorer/src/up_buttons.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/configs/lpc4330-xplorer/src/up_buttons.c b/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
index d99ee2356..a3f4c4975 100644
--- a/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
+++ b/nuttx/configs/lpc4330-xplorer/src/up_buttons.c
@@ -93,17 +93,17 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
int i;
@@ -119,7 +119,7 @@ void up_buttoninit(void)
* Name: up_buttons
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons.
*
@@ -159,7 +159,7 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*
* up_irqbutton() may be called to register an interrupt handler that will
@@ -93,17 +93,17 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -119,7 +119,7 @@ void up_buttoninit(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons.
@@ -159,7 +159,7 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_irqbutton() may be called to register button interrupt handlers.
*